import sys
from pathlib import Path

import click
from ics import Calendar

from calh.filter import CalendarFilter


@click.group()
def cli():
    pass


def create_single_year_dataset():
    input_file = Path(__file__).parent / "func" / "data" / "urlab.ics"
    output_file = Path(__file__).parent / "func" / "data" / "02-04_05-05-2020_urlab.ics"
    CalendarFilter.filter(
        input_file=input_file,
        start_date="2020-02-04",
        end_date="2020-05-05",
        output_format="ics",
        output_file=output_file,
    )


def create_multiple_year_dataset():
    input_file = Path(__file__).parent / "func" / "data" / "urlab.ics"
    output_file = Path(__file__).parent / "func" / "data" / "2018-2020_urlab.ics"
    cal_filter = CalendarFilter.filter(
        input_file=input_file,
        start_date="2018-01-01",
        end_date="2020-01-01",
        output_format="ics",
        output_file=output_file,
    )


@cli.command()
def create_test_data():
    create_single_year_dataset()
    create_multiple_year_dataset()


if __name__ == "__main__":
    sys.exit(cli())



#!/usr/bin/env python

"""Tests for `calh` package."""
from pathlib import Path

import pytest
from click.testing import CliRunner
from ics import Calendar

from calh.filter import CalendarFilter
from . import CURR_DIR

# These are the last 10 events from urlab.ics from 02 April to 05 May
# [<Event 'SmartMonday de Mai 2020' begin:2020-05-04T17:00:12+00:00 end:2020-05-04T19:30:12+00:00>,
#  <Event 'Workshop Make no2' begin:2020-03-12T11:00:39+00:00 end:2020-03-12T13:00:39+00:00>,
#  <Event 'Workshop Make no1' begin:2020-03-10T11:00:40+00:00 end:2020-03-10T13:00:41+00:00>,
#  <Event 'SmartMonday de Mars 2020' begin:2020-03-09T18:00:22+00:00 end:2020-03-09T21:30:22+00:00>,
#  <Event 'Réunion débat timent' begin:2020-02-25T17:30:00+00:00 end:2020-02-25T19:00:00+00:00>,
#  <Event 'Mardi C'est root-me' begin:2020-02-18T18:00:00+00:00 end:2020-02-18T20:00:00+00:00>,
#  <Event 'Workshop réseaux de neurones' begin:2020-02-17T17:30:00+00:00 end:2020-02-17T22:00:00+00:00>,
#  <Event '« Et demain ? »' begin:2020-02-13T15:30:01+00:00 end:2020-02-13T17:30:01+00:00>,
#  <Event 'VenDreDDi' begin:2020-02-07T16:00:10+00:00 end:2020-02-07T21:00:10+00:00>,
#  <Event 'La première réunion du quadri' begin:2020-02-04T18:30:34+00:00 end:2020-02-04T20:00:34+00:00>]


def test_filter_calendar_without_any_filter():
    filtered_calendar = CalendarFilter(
        input_file=Path(CURR_DIR / "data" / "ics" / "02-04_05-05-2020_urlab.ics"),
    )
    filtered_calendar.filter_calendars()
    result = filtered_calendar.result
    expected_result = [
        {"name": "SmartMonday de Mai 2020", "start": "2020-05-04", "duration": 9000.0},
        {"name": "Mardi C'est root-me", "start": "2020-02-18", "duration": 7200.0},
        {"name": "Workshop Make no1", "start": "2020-03-10", "duration": 7201.0},
        {"name": "VenDreDDi", "start": "2020-02-07", "duration": 18000.0},
        {
            "name": "La première réunion du quadri",
            "start": "2020-02-04",
            "duration": 5400.0,
        },
        {"name": "Réunion débat timent", "start": "2020-02-25", "duration": 5400.0},
        {
            "name": "SmartMonday de Mars 2020",
            "start": "2020-03-09",
            "duration": 12600.0,
        },
        {"name": "Workshop Make no2", "start": "2020-03-12", "duration": 7200.0},
        {
            "name": "Workshop réseaux de neurones",
            "start": "2020-02-17",
            "duration": 16200.0,
        },
        {"name": "« Et demain ? »", "start": "2020-02-13", "duration": 7200.0},
    ]
    assert result == expected_result


def test_filter_cals_by_date():
    filtered_calendar = CalendarFilter(
        input_file=Path(CURR_DIR / "data" / "ics" / "02-04_05-05-2020_urlab.ics"),
        start_date="2020-02-04",
        end_date="2020-05-05",
    )
    filtered_calendar.filter_calendars()
    result = filtered_calendar.result
    expected_result = [
        {"name": "SmartMonday de Mai 2020", "start": "2020-05-04", "duration": 9000.0},
        {"name": "Mardi C'est root-me", "start": "2020-02-18", "duration": 7200.0},
        {"name": "Workshop Make no1", "start": "2020-03-10", "duration": 7201.0},
        {"name": "VenDreDDi", "start": "2020-02-07", "duration": 18000.0},
        {
            "name": "La première réunion du quadri",
            "start": "2020-02-04",
            "duration": 5400.0,
        },
        {"name": "Réunion débat timent", "start": "2020-02-25", "duration": 5400.0},
        {
            "name": "SmartMonday de Mars 2020",
            "start": "2020-03-09",
            "duration": 12600.0,
        },
        {"name": "Workshop Make no2", "start": "2020-03-12", "duration": 7200.0},
        {
            "name": "Workshop réseaux de neurones",
            "start": "2020-02-17",
            "duration": 16200.0,
        },
        {"name": "« Et demain ? »", "start": "2020-02-13", "duration": 7200.0},
    ]
    assert result == expected_result


def test_filter_calendar_by_re_pattern():
    filtered_calendar = CalendarFilter(
        input_file=Path(CURR_DIR / "data" / "ics" / "02-04_05-05-2020_urlab.ics"),
        re_pattern="workshop",
    )
    filtered_calendar.filter_calendars()
    result = filtered_calendar.result
    expected_result = [
        {"name": "Workshop Make no1", "start": "2020-03-10", "duration": 7201.0},
        {"name": "Workshop Make no2", "start": "2020-03-12", "duration": 7200.0},
        {
            "name": "Workshop réseaux de neurones",
            "start": "2020-02-17",
            "duration": 16200.0,
        },
    ]
    assert result == expected_result


def test_filter_calendar_by_date_and_re_pattern():
    filtered_calendar = CalendarFilter(
        input_file=Path(CURR_DIR / "data" / "ics" / "urlab.ics"),
        re_pattern="workshop",
        start_date="2020-02-04",
        end_date="2020-05-04",
    )
    filtered_calendar.filter_calendars()
    result = filtered_calendar.result
    assert result == [
        {
            "name": "Workshop réseaux de neurones",
            "start": "2020-02-17",
            "duration": 16200.0,
        },
        {"name": "Workshop Make no2", "start": "2020-03-12", "duration": 7200.0},
        {"name": "Workshop Make no1", "start": "2020-03-10", "duration": 7201.0},
    ]


def test_filter_calendar_to_output_ics():
    filtered_calendar = CalendarFilter(
        input_file=CURR_DIR / "data" / "ics" / "urlab.ics",
        start_date="2020-02-04",
        end_date="2020-05-05",
        output_format="ics",
    )
    filtered_calendar.filter_calendars()
    result = filtered_calendar.result
    assert isinstance(result, Calendar)
    with open(Path(CURR_DIR / "data" / "ics" / "02-04_05-05-2020_urlab.ics")) as in_f:
        expected_cal = Calendar(in_f.read())
    assert result.events == expected_cal.events



""" Filter calendar """

import json
import re
import warnings
from collections import namedtuple
from pathlib import Path
from typing import Optional, List, Callable, Union

import arrow
from arrow import Arrow
from ics import Calendar, Event

DATE_FMT = "YYYY-MM-DD"


class CalendarFilter:
    def __init__(
        self,
        input_file: Path,
        re_pattern: Optional[str] = None,
        start_date: Optional[str] = None,
        end_date: Optional[str] = None,
        output_format="json",
    ):
        """Filter calendar and output in either ics or json format

        Arguments:
            input_file {Path} -- filepath to calendar file in ics format

        Keyword Arguments:
            re_pattern {Optional[str]} -- regular expression pattern to 
            filter event.name and event.description (default: {None})
            start_date {Optional[str]} -- start date (inclusive) in YYYY-MM-DD (default: {None})
            end_date {Optional[str]} -- end date (inclusive) in YYYY-MM-DD (default: {None})
            If end_date is None, the current date with `arrow.now()` is set.
            output_format {str} -- output file format either in ics (calendar) format or json (default: {"json"})

        Raises:
            ValueError: if end_date is given but not for the start_date
        """
        self.input_file = input_file
        self.re_pattern = re_pattern
        self.start_date = start_date
        self.end_date = end_date
        self.output_format = output_format

        if self.start_date and (self.end_date is None):
            self.end_date = arrow.now()
            warnings.warn(f"end_date is set to {self.end_date!s}")

        if self.end_date and (self.start_date is None):
            raise ValueError(f"start_date is required")

        if self.start_date and isinstance(self.start_date, str):
            self.start_date = arrow.get(self.start_date, DATE_FMT)
        if self.end_date and isinstance(self.end_date, str):
            self.end_date = arrow.get(self.end_date, DATE_FMT)

        if output_format == "json":
            self.result = []
        if output_format == "ics":
            self.result = Calendar()

    def create_filter_functions(self) -> [Callable]:
        result = []
        if self.re_pattern:
            result.append(self.check_re_pattern)
        if self.start_date and self.end_date:
            result.append(self.check_within_date)
        return result

    def get_calendars(self) -> List[Calendar]:
        with open(self.input_file, "rt") as in_f:
            cal_text = in_f.read()
            cals = Calendar.parse_multiple(cal_text)
        return cals

    def filter_calendars(self):
        filter_functions = self.create_filter_functions()
        cals = self.get_calendars()
        for cal in cals:
            self.filter_events(cal=cal, filter_functions=filter_functions)

    def filter_events(self, cal: Calendar, filter_functions):
        for e in cal.events:
            if all(f(e) for f in filter_functions):
                self.add_result(result=self.result, event=e)
            else:
                continue

    def check_re_pattern(self, event: Event) -> bool:
        if re.search(
            self.re_pattern, fr"{event.name} {event.description}", re.IGNORECASE
        ):
            return True
        return False

    def check_within_date(self, event: Event) -> bool:
        if self.start_date <= event.begin <= self.end_date:
            return True
        return False

    @staticmethod
    def add_result(result: Union[List, Calendar], event: Event):
        if type(result) is Calendar:
            result.events.add(event)
        if type(result) is list:
            result.append(
                {
                    "name": event.name,
                    "start": event.begin.format(DATE_FMT),
                    "duration": event.duration.total_seconds(),
                }
            )

    def save_as(self, output_file):
        with open(output_file, "w") as out_f:
            if isinstance(self.result, Calendar):
                out_f.write(str(self.result))
            if isinstance(self.result, list):
                json.dump(self.result, out_f)

    @classmethod
    def filter(
        cls,
        input_file,
        output_file,
        re_pattern=None,
        start_date=None,
        end_date=None,
        output_format="json",
    ):
        filter_calendar = cls(
            input_file=input_file,
            re_pattern=re_pattern,
            start_date=start_date,
            end_date=end_date,
            output_format=output_format,
        )
        filter_calendar.filter_calendars()
        filter_calendar.save_as(output_file)



import arrow
import pytest
from calh.filter import CalendarFilter


def test_calendar_filter_with_no_end_date():
    date_format = "%Y-%m-%d"
    cal = CalendarFilter(input_file="foo", start_date="2020-01-01", end_date=None)
    expected_end_date = arrow.now().strftime(date_format)
    assert cal.end_date.strftime(date_format) == expected_end_date


def test_calendar_filter_with_no_start_date():
    with pytest.raises(ValueError) as e:
        cal = CalendarFilter(input_file="foo", start_date=None, end_date="2020-01-01")
    assert 'start_date is required' in str(e)



import pandas as pd
import pytest
from pandas.testing import assert_frame_equal

from calh.visualization import Heatmap
from . import CURR_DIR


def test_date_df_for_heatmap_from_ics_input():
    hm = Heatmap(input_data=CURR_DIR / "data" / "ics" / "02-04_05-05-2020_urlab.ics")
    expected_date_df = pd.DataFrame(
        [
            {"name": 1, "weekday": 1, "date": "2020-02-04", "week": 6, "month": 2},
            {"name": 1, "weekday": 4, "date": "2020-02-07", "week": 6, "month": 2},
            {"name": 1, "weekday": 3, "date": "2020-02-13", "week": 7, "month": 2},
            {"name": 1, "weekday": 0, "date": "2020-02-17", "week": 8, "month": 2},
            {"name": 1, "weekday": 1, "date": "2020-02-18", "week": 8, "month": 2},
            {"name": 1, "weekday": 1, "date": "2020-02-25", "week": 9, "month": 2},
            {"name": 1, "weekday": 0, "date": "2020-03-09", "week": 11, "month": 3},
            {"name": 1, "weekday": 1, "date": "2020-03-10", "week": 11, "month": 3},
            {"name": 1, "weekday": 3, "date": "2020-03-12", "week": 11, "month": 3},
            {"name": 1, "weekday": 0, "date": "2020-05-04", "week": 19, "month": 5},
        ]
    )
    expected_date_df["date"] = pd.to_datetime(expected_date_df["date"], utc=True)
    date_df = hm.create_date_df(hm.df)
    assert_frame_equal(
        date_df.reset_index(drop=True),
        expected_date_df.reset_index(drop=True),
        check_dtype=False,
        check_index_type=False,
    )


@pytest.mark.mpl_image_compare(
    savefig_kwargs={"bbox_inches": "tight"},
    baseline_dir=str(CURR_DIR / "data" / "png"),
    filename="test_create_heatmap_from_ics_input.png",
)
def test_create_heatmap_from_ics_input():
    input_file = CURR_DIR / "data" / "ics" / "02-04_05-05-2020_urlab.ics"
    output_file = CURR_DIR / "data" / "png" / "02-04_05-05-2020_urlab.png"
    hm = Heatmap(input_data=input_file, full_year=True)
    hm.draw(title="test")
    return hm.result



"""Console script for calh."""
import json
import sys

import click
import click_spinner


@click.group(invoke_without_command=True)
@click.option("-v", "--version", is_flag=True, default=False)
def cli(version):
    if version:
        import calh

        click.echo(f"Version: {calh.__version__}")


@cli.command()
@click.option(
    "--input-file", required=True, type=click.Path(), help="Calendar filepath"
)
@click.option("--re-pattern", default=None, help="Regular expression pattern")
@click.option(
    "--start-date", default=None, help="Date starts from. Format in YYYY-MM-DD"
)
@click.option("--end-date", default=None, help="Date untill. Format in YYYY-MM-DD")
@click.option(
    "--output-format",
    type=click.Choice(["json", "ics"]),
    default="json",
    help="Output format",
)
@click.option("--output-file", type=click.Path(), help="Filepath for your output")
def filter_calendar(
    input_file, re_pattern, start_date, end_date, output_format, output_file
):
    """
    Filter ics-format calendar
    """
    from calh.filter import CalendarFilter

    with click_spinner.spinner():
        CalendarFilter.filter(
            input_file=input_file,
            re_pattern=re_pattern,
            start_date=start_date,
            end_date=end_date,
            output_format=output_format,
            output_file=output_file,
        )

    click.echo(f"Your filtered calendar is ready: {output_file}")


@cli.command()
@click.option("--input-file", required=True, type=click.Path(), help="Input file")
@click.option("--title", required=True, help="Title of the calendar")
@click.option("--width", default=None, help="Width in inch")
@click.option("--height", default=None, help="Height in inch")
@click.option("--full-year", is_flag=True, default=False, help="Show the full year")
@click.option("--output-file", type=click.Path(), help="out json file")
def draw_calendar(input_file, title, full_year, width, height, output_file):
    """
    Drawing calender with weekdays and iso-weeks
    """
    from calh.visualization import Heatmap

    with click_spinner.spinner():
        Heatmap.create(
            input_file=input_file,
            full_year=full_year,
            output_file=output_file,
            title=title,
            width=width,
            height=height,
        )

    click.echo(f"Your calendar is ready: {output_file}")


if __name__ == "__main__":
    sys.exit(cli())  # pragma: no cover



import json
from pathlib import Path

from click.testing import CliRunner

from calh.cli import cli

CURR_DIR = Path(__file__).parent


def test_filter_calendar():
    runner = CliRunner()
    input_file = f'{Path(CURR_DIR / "data" / "ics"/ "urlab.ics")}'
    output_file = f'{Path(CURR_DIR / "data" / "json"/"filtered_urlab.json")}'
    result = runner.invoke(
        cli,
        [
            "filter-calendar",
            "--input-file",
            input_file,
            "--re-pattern",
            "workshop",
            "--start-date",
            "2020-02-04",
            "--end-date",
            "2020-05-05",
            "--output-file",
            output_file,
        ],
    )
    assert result.exit_code == 0
    assert Path(output_file).exists()
    Path(output_file).unlink()


def draw_calendar(input_file, output_file, full_year=False):
    runner = CliRunner()
    cmd = [
        "draw-calendar",
        "--input-file",
        input_file,
        "--title",
        "Test",
        "--output-file",
        output_file,
    ]
    if full_year:
        cmd.append("--full-year")
    result = runner.invoke(cli, cmd)
    return result


def test_draw_calendar():
    input_file = f'{Path(CURR_DIR / "data" / "json" / "02-04_05-05-2020_urlab.json")}'
    output_file = f'{Path(CURR_DIR / "data" / "png" /"filtered_urlab.png")}'
    result = draw_calendar(input_file=input_file, output_file=output_file)
    assert result.exit_code == 0
    assert Path(output_file).exists()
    Path(output_file).unlink()


def test_draw_calendar_with_full_year():
    input_file = f'{Path(CURR_DIR / "data" / "json" / "02-04_05-05-2020_urlab.json")}'
    output_file = (
        f'{Path(CURR_DIR / "data" / "png" / "filtered_urlab-with-full-year.png")}'
    )
    result = draw_calendar(
        input_file=input_file, output_file=output_file, full_year=True
    )
    assert result.exit_code == 0
    assert Path(output_file).exists()
    Path(output_file).unlink()



import calendar
import datetime
import json
import math
from datetime import timedelta
from pathlib import Path
from typing import Union, Dict, List

import matplotlib.pyplot as plt
import numpy as np
import pandas as pd
import seaborn as sns
from ics import Calendar

from calh.filter import CalendarFilter


class Heatmap:
    def __init__(self, input_data: Union[Path, List], full_year=True, utc=True):
        """Generate heatmap

        Arguments:
            input_data {Union[Path, List]} -- Input data can be a filepath (Path) or a python list object

        Keyword Arguments:
            full_year {bool} -- Show the whole year, if True.
            Otherwise it will show only months where events are found (default: {True})
            utc {bool} -- UTC DatetimeIndex  if True.

        Raises:
            ValueError: if the file_path contains no data
        """

        self.input_data = input_data
        self.full_year = full_year
        self.utc = utc
        data = self.read_input_data(input_data)
        self.df = self.create_df(data=data, utc=self.utc)
        self.result = None

    def read_input_data(self, input_data):
        """Reading input data

        Arguments:
            input_data {Union[Path, List]} -- Input data can be a filepath (Path) or a python list object

        Raises:
            ValueError: if Object is not a list
            ValueError: if data is empty
        """
        input_reader = {
            ".ics": self.read_ics,
            ".json": self.read_json,
        }
        try:
            reader = input_reader[Path(input_data).suffix]
            data = reader(input_data)
        except TypeError:
            if isinstance(self.input_data, list):
                # This is a shallow-copy to keep data immutable!
                data = input_data.copy()
            else:
                raise ValueError("Unknown input")
        if not data:
            raise ValueError("No data")
        return data

    @staticmethod
    def read_ics(file_path: Path) -> List[Dict]:
        with open(file_path, "rt") as in_f:
            cals = Calendar.parse_multiple(in_f.read())
        result = []
        for c in cals:
            for e in c.events:
                CalendarFilter.add_result(result=result, event=e)
        return result

    @staticmethod
    def read_json(file_path: Path) -> List[Dict]:
        with open(file_path, "r") as in_f:
            result = json.load(in_f)
        return result

    @staticmethod
    def create_df(data, utc):
        df = pd.DataFrame(data)
        df["start"] = pd.to_datetime(df["start"], utc=utc)
        df["date"] = df["start"].dt.floor("d")
        return df

    def create_date_df(self, df):
        by_date = df.groupby("date")[["name"]].count()
        by_date = by_date.sort_index()
        by_date["weekday"] = by_date.index.weekday
        by_date["date"] = by_date.index
        by_date["week"] = by_date.date.apply(lambda x: int(x.isocalendar()[1]))
        by_date["month"] = by_date.index.month
        return by_date

    def get_activities(
        self, date_df: pd.DataFrame, min_week: int, max_week: int
    ) -> np.ndarray:
        """Create a matrix of weekday and isoweek

        Arguments:
            date_df {pd.DataFrame} -- dataframe containing date properties
            min_week {int} -- smallest week number
            max_week {int} -- largest week number

        Returns:
            np.ndarray -- a matrix of weekday (y) and isoweek (x)
        """
        activities = np.full((7, (max_week - min_week) + 1), np.nan)
        for idx, row in date_df.iterrows():
            normalized_week = row["week"] - min_week
            activities[row["weekday"]][normalized_week] = row["name"]
        return activities

    @staticmethod
    def isomonth_number_for(year: int, week: int) -> int:
        first = datetime.date(year, 1, 1)
        base = 1 if first.isocalendar()[1] == 1 else 8
        date = first + timedelta(days=base - first.isocalendar()[2] + 7 * (week - 1))
        return date.month

    def create_labels(
        self, min_week: int, max_week: int, year: int,
    ):
        """Create x_label and y_label for a heatmap.

        Arguments:
            min_week {int} -- smallest number of week
            max_week {int} -- largest number of week
            year {int} -- year of calendar

        Returns:
            tuple -- a tuple containing a list of `x_labels` and a list of `y_label`
        """
        month_nums = [
            self.isomonth_number_for(year=year, week=wk + 1)
            for wk in range(min_week, max_week)
        ]
        x_labels = [calendar.month_abbr[month_nums[0]]]
        for i in range(1, len(month_nums) - 1):
            if month_nums[i - 1] != month_nums[i]:
                month = calendar.month_abbr[month_nums[i]]
                x_labels.append(month)
            else:
                x_labels.append("")

        y_labels = ["Mon", "", "Wed", "", "Fri", "", "Sun"]
        return (x_labels, y_labels)

    @staticmethod
    def get_unique_years(df) -> List[int]:
        return list(pd.DatetimeIndex(df["date"]).year.unique())

    def draw(self, title, width=None, height=None):
        years = sorted(self.get_unique_years(self.df), reverse=True)
        num_year = len(years)
        if width is None:
            width = 20
        if height is None:
            height = 5 * num_year // 2
        fig, axs = plt.subplots(num_year, figsize=(width, height), squeeze=False)
        fig.patch.set_facecolor("white")
        fig.tight_layout(pad=3.0)
        for idx, year in enumerate(years):
            yearly_df = self.df[self.df["date"].dt.year == year]
            ax = axs[idx, 0]
            self.draw_yearly(yearly_df=yearly_df, ax=ax, year=year)
        fig.suptitle(title.title(), fontsize=20, verticalalignment="top", y=1.1)
        self.result = fig

    @staticmethod
    def isoweek_number_for(year: int):
        last_week = datetime.date(year, 12, 28)
        return last_week.isocalendar()[1]

    def draw_yearly(self, yearly_df, ax, year):
        date_df = self.create_date_df(yearly_df)
        if self.full_year:
            min_week = 1
            max_week = self.isoweek_number_for(year)
        else:
            min_week = date_df.week.min()
            max_week = date_df.week.max()
        activities = self.get_activities(
            date_df=date_df, min_week=min_week, max_week=max_week
        )
        x_labels, y_labels = self.create_labels(
            min_week=min_week, max_week=max_week, year=year,
        )
        ax.set_title(year, fontsize=10, loc="left")
        ax.xaxis.tick_top()
        ax.tick_params(axis="both", which="both", length=0)
        ax.set_facecolor("#ebedf0")

        sns.heatmap(
            activities,
            linewidths=2,
            linecolor="white",
            square=True,
            mask=np.isnan(activities),
            cmap="Greens",
            vmin=0,
            vmax=100,
            cbar=False,
            ax=ax,
        )

        ax.set_yticklabels(y_labels, rotation=0)
        ax.set_xticklabels(x_labels, ha="left")

    def save_as(self, output_file, *args, **kwargs):
        self.result.savefig(output_file, bbox_inches="tight", *args, **kwargs)

    @classmethod
    def create(
        cls, input_file, output_file, title, full_year=True, width=None, height=None
    ):
        hm = Heatmap(input_data=input_file, full_year=full_year)
        hm.draw(title=title, width=width, height=height)
        hm.save_as(output_file=output_file)



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements = [
    "Click>=7.0",
    "click-spinner>=0.1.10",
    "ics>=0.7",
    "matplotlib>=3.2.1",
    "notebook>=6.0.3",
    "numpy>=1.18.3",
    "pandas>=1.0.3",
    "pyprojroot>=0.2.0",
    "seaborn>=0.10.1",
]

setup_requirements = ["pytest-runner", "ipython==7.13.0"]

test_requirements = [
    "pytest>=3",
    "pytest-mpl==0.11",
]

setup(
    author="Ricky Lim",
    author_email="rlim.email@gmail.com",
    python_requires=">=3.6",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    description="Calendar Heatmap",
    entry_points={"console_scripts": ["calh=calh.cli:cli",],},
    install_requires=requirements,
    license="Apache Software License 2.0",
    long_description=readme + "\n\n" + history,
    long_description_content_type="text/x-rst",
    include_package_data=True,
    keywords="calh",
    name="calh",
    packages=find_packages(include=["calh", "calh.*"]),
    setup_requires=setup_requirements,
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/ricky-lim/calh",
    version="2.1.0",
    zip_safe=False,
)
